==> LEPL-4.0.2.zip: LEPL-4.0.2/src/lepl/matchers/_test/__init__.py <==

# The contents of this file are subject to the Mozilla Public License
# (MPL) Version 1.1 (the "License"); you may not use this file except
# in compliance with the License. You may obtain a copy of the License
# at http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS"
# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
# the License for the specific language governing rights and
# limitations under the License.
#
# The Original Code is LEPL (http://www.acooke.org/lepl)
# The Initial Developer of the Original Code is Andrew Cooke.
# Portions created by the Initial Developer are Copyright (C) 2009-2010
# Andrew Cooke (andrew@acooke.org). All Rights Reserved.
#
# Alternatively, the contents of this file may be used under the terms
# of the LGPL license (the GNU Lesser General Public License,
# http://www.gnu.org/licenses/lgpl.html), in which case the provisions
# of the LGPL License are applicable instead of those above.
#
# If you wish to allow use of your version of this file only under the
# terms of the LGPL License and not to allow others to use your version
# of this file under the MPL, indicate your decision by deleting the
# provisions above and replace them with the notice and other provisions
# required by the LGPL License.  If you do not delete the provisions
# above, a recipient may use your version of this file under either the
# MPL or the LGPL License.


'''
Tests for the lepl.matchers package.
'''

from sys import version

# we need to import all files used in the automated self-test

# pylint: disable-msg=E0611
#@PydevCodeAnalysisIgnore
import lepl.matchers._test.combine
import lepl.matchers._test.core
import lepl.matchers._test.derived
import lepl.matchers._test.error
import lepl.matchers._test.memo
import lepl.matchers._test.operators
import lepl.matchers._test.separators
if version[0] == '2':
    import lepl.matchers._test.support
else:
    import lepl.matchers._test.support3
import lepl.matchers._test.variables

==> LEPL-4.1.zip: LEPL-4.1/src/lepl/matchers/_test/__init__.py <==

# The contents of this file are subject to the Mozilla Public License
# (MPL) Version 1.1 (the "License"); you may not use this file except
# in compliance with the License. You may obtain a copy of the License
# at http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS"
# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
# the License for the specific language governing rights and
# limitations under the License.
#
# The Original Code is LEPL (http://www.acooke.org/lepl)
# The Initial Developer of the Original Code is Andrew Cooke.
# Portions created by the Initial Developer are Copyright (C) 2009-2010
# Andrew Cooke (andrew@acooke.org). All Rights Reserved.
#
# Alternatively, the contents of this file may be used under the terms
# of the LGPL license (the GNU Lesser General Public License,
# http://www.gnu.org/licenses/lgpl.html), in which case the provisions
# of the LGPL License are applicable instead of those above.
#
# If you wish to allow use of your version of this file only under the
# terms of the LGPL License and not to allow others to use your version
# of this file under the MPL, indicate your decision by deleting the
# provisions above and replace them with the notice and other provisions
# required by the LGPL License.  If you do not delete the provisions
# above, a recipient may use your version of this file under either the
# MPL or the LGPL License.


'''
Tests for the lepl.matchers package.
'''

from sys import version

# we need to import all files used in the automated self-test

# pylint: disable-msg=E0611
#@PydevCodeAnalysisIgnore
import lepl.matchers._test.combine
import lepl.matchers._test.core
import lepl.matchers._test.derived
import lepl.matchers._test.error
import lepl.matchers._test.memo
import lepl.matchers._test.operators
import lepl.matchers._test.separators
import lepl.matchers._test.support
import lepl.matchers._test.transform
